/**
  CAN Generated Driver API Header File

  @Company
    Microchip Technology Inc.

  @File Name
    can.h

  @Summary
    This is the generated header file for the ECAN driver using PIC10 / PIC12 / PIC16 / PIC18 MCUs

  @Description
    This header file provides APIs driver for CAN.
    Generation Information :
        Product Revision  :  PIC10 / PIC12 / PIC16 / PIC18 MCUs - 1.65.2
        Device            :  PIC18F26K80
        Driver Version    :  2.11
    The generated drivers are tested against the following:
        Compiler          :  XC8 1.45
        MPLAB 	          :  MPLAB X 4.15
*/

/*
    (c) 2018 Microchip Technology Inc. and its subsidiaries. 
    
    Subject to your compliance with these terms, you may use Microchip software and any 
    derivatives exclusively with Microchip products. It is your responsibility to comply with third party 
    license terms applicable to your use of third party software (including open source software) that 
    may accompany Microchip software.
    
    THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER 
    EXPRESS, IMPLIED OR STATUTORY, APPLY TO THIS SOFTWARE, INCLUDING ANY 
    IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS 
    FOR A PARTICULAR PURPOSE.
    
    IN NO EVENT WILL MICROCHIP BE LIABLE FOR ANY INDIRECT, SPECIAL, PUNITIVE, 
    INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE, COST OR EXPENSE OF ANY KIND 
    WHATSOEVER RELATED TO THE SOFTWARE, HOWEVER CAUSED, EVEN IF MICROCHIP 
    HAS BEEN ADVISED OF THE POSSIBILITY OR THE DAMAGES ARE FORESEEABLE. TO 
    THE FULLEST EXTENT ALLOWED BY LAW, MICROCHIP'S TOTAL LIABILITY ON ALL 
    CLAIMS IN ANY WAY RELATED TO THIS SOFTWARE WILL NOT EXCEED THE AMOUNT 
    OF FEES, IF ANY, THAT YOU HAVE PAID DIRECTLY TO MICROCHIP FOR THIS 
    SOFTWARE.
*/
/*  ̃\[X́A"MODE 0"pRXB0IE/ERRIE/WAKIELɂMCCŐꂽłB

    2018-10-30  ޒH[(ނ)  Rg̓{ꉻ
*/


#ifndef ECAN_H
#define ECAN_H

/**
  Section: Included Files
*/

#include <stdbool.h>
#include <stdint.h>

#ifdef __cplusplus  // Provide C++ Compatibility

    extern "C" {

#endif

/**

Global Defines  

*/
typedef union {

    struct {
        uint8_t idType;
        uint32_t id;
        uint8_t dlc;
        uint8_t data0;
        uint8_t data1;
        uint8_t data2;
        uint8_t data3;
        uint8_t data4;
        uint8_t data5;
        uint8_t data6;
        uint8_t data7;
    } frame;
    uint8_t array[14];
} uCAN_MSG;

/**
 Defines
*/

#define dSTANDARD_CAN_MSG_ID_2_0B 1  // W̎ʎqID
#define dEXTENDED_CAN_MSG_ID_2_0B 2  // g̎ʎqID

/**
  Section: CAN APIs
*/
void ECAN_ISR_ECAN_RXB0I(void);
void ECAN_ISR_ECAN_ERRI(void);
void ECAN_ISR_ECAN_WAKI(void);

/**
    @Summary
        ECAN_Initialize - ECANW[܂B

    @Description
        ̃[`́AECANW[̑SẴWX^(tB^A}XNAyуrbg^C~O)
        p[^ݒ肵܂B
        RtBM[VE[hɂāAECANWX^Am[}E[hɐ؂ւ܂B
        ̑̃WX^ꍇ́Ã[`ɒǉ܂傤B
        A荞ݏ̌^gvO͐Ă邪ALɂ郍WbNŋLq܂傤B

    @Preconditions 
        None

    @Param
        None
  
    @Returns
        None
 
    @Example
        <code>
        ECAN_Initialize();  
        </code>                                                                      
*/
void ECAN_Initialize(void);
/**
                                                                           
    @Summary
        CAN_sleep - CANW[X[vԂɂ鏈

    @Description
        ̃[`́ACANW[X[vԂɂOɁAoXANeBreB@\
        LɂĉB

    @Param
        None 

    @Returns
        None   

    @Example
        <code>
        CAN_sleep();  
        </code> 
                                                                           
*/

void CAN_sleep(void);

/**
    @Summary
        CAN_transmit - bZ[Wf[^𑗐M鏈

    @Description
        TXB0>TXB1>TXB2̏ŋ̑Mobt@T܂B
        ϊꂽʎqIDADLCAy8f[^oCg̒lΉ郌WX^ɏ񂾌A
        MvXe[^X(TXREQ)rbgݒ肵܂B

    @Param
        M郁bZ[Wf[^eLڏꏊւ̃|C^

    @Returns
        bZ[WMobt@Ƀ[hꂽꍇTrueAȊOFalseԂ܂B

    @Example
        <code>
        uCAN_MSG txMessage;
        CAN_transmit(&txMessage);  
        </code>                                                                             
*/
uint8_t CAN_transmit(uCAN_MSG *tempCanMsg);


/**

	@Summary
		CAN_receive - bZ[Wf[^M鏈

	@Description
		MbZ[WCANobt@RXB0>RXB1̏Ƀ`FbN܂B
          LȃbZ[WMƁAECANWX^̒l͈ꎞIȃ\tgEFAWX^
          Rs[܂B
          IDWX^̒l͎IɎʎqIDɕϊ܂B

	@Param
		MbZ[Wf[^ei[ꏊւ̃|C^

	@Returns
		VbZ[WLꍇTrueAȊOFalseԂ܂B
  
	@Example
		<code>
		uCAN_MSG rxMessage;
		CAN_receive(&rxMessage);  
		</code> 
                                                                             
*/
uint8_t CAN_receive(uCAN_MSG *tempCanMsg);

/**
 
	@Summary
		CAN_messagesInBuffer - obt@ɂ郁bZ[W̐mF鏈
 
	@Description
		obt@[(RXB0/RXB1)̃bZ[W`FbN܂B
	
	@Param
		None

	@Returns
		obt@̃bZ[W̑Ԃ܂B

	@Example
		<code>
		uint8_t nrMsg;
		nrMsg = CAN_messagesInBuffer();  
		</code>                                                                            
*/
uint8_t CAN_messagesInBuffer(void);

/**

	@Summary
		CAN_isBusOff - MW["oXIt"ł邩ǂ𒲂ׂ鏈

	@Description
		

	@Param
		None

	@Returns
		MW[oXIt̏ꍇTrueAłȂꍇFalseԂ܂B
          1 = MG[JE^  256
          0 = MG[JE^  255

	@Example
		<code>
		uint8_t busOff;
		busOff = CAN_isBusOff();  
		</code> 
                                                  
*/

uint8_t CAN_isBusOff(void);

/**

	@Summary
		CAN_isRXErrorPassive - MW["G[pbVu"ł邩ǂ𒲂ׂ鏈

	@Description
		

	@Param
		None
 
	@Returns
 		MW[G[pbVuɂꍇTrueAłȂꍇFalseԂ܂B                                                    
          1 = MG[JE^  128
          0 = MG[JE^  127

 	@Example
		<code>
		uint8_t errRxPasive;
		errRxPasive = CAN_isRXErrorPassive();
		</code>     
                                                    
 */
 
uint8_t CAN_isRXErrorPassive(void);

/**

	@Summary
		CAN_isTXErrorPassive - MW["G[pbVu"ł邩ǂ𒲂ׂ鏈

	@Description
		

	@Param
		None

	@Returns
 		MW[G[pbVuɂꍇTrueAłȂꍇFalseԂ܂B                                                    
          1 = MG[JE^  128
          0 = MG[JE^  127

	@Example
		<code>
		uint8_t errTxPasive;
		errTxPasive = CAN_isTXErrorPassive();  
		</code>       

*/

uint8_t CAN_isTXErrorPassive(void);


#ifdef __cplusplus  // Provide C++ Compatibility
    }
#endif

#endif // ECAN_H

/**
 End of File
*/
